@@ -9,7 +9,7 @@
 
 package Glib::GenPod;
 
-our $VERSION = '1.314';
+our $VERSION = '1.321';
 
 use strict;
 use warnings;
@@ -278,7 +278,14 @@ sub xsdoc2pod
 		# end.  But all the other =head1 below need a closing =cut.
 
 		print "=head1 NAME\n\n$package";
-		print ' - '.$pkgdata->{blurb} if (exists ($pkgdata->{blurb}));
+		if (exists ($pkgdata->{blurb})) {
+			print ' - '.$pkgdata->{blurb};
+		} else {
+			my $cname = convert_to_cname ($package);
+			if (defined $cname) {
+				print " - wrapper for $cname";
+			}
+		}
 		print "\n\n=cut\n\n";
 
 		#                   pods            , position 
@@ -1524,6 +1531,22 @@ sub mkdir_p {
 	} while (@dirs);
 }
 
+sub convert_to_cname {
+	my $perlname = shift;
+	my $cname = $perlname;
+	$cname =~ s/^Gtk2::Gdk::/Gdk/;
+	$cname =~ s/^Gtk2::/Gtk/;
+	$cname =~ s/^Gnome2::Bonobo::/Bonobo/;
+	$cname =~ s/^Gnome2::/Gnome/;
+	$cname =~ s/:://g;
+	my $tmp;
+	eval { $tmp = Glib::Type->package_from_cname($cname); };
+	if ($@ || $tmp ne $perlname) {
+		return;
+	}
+	return $cname;
+}
+
 1;
 __END__
 
